<?php

namespace Btravel\Externaldatum\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Externaldatum\Models\Gebeco;

class GebecoPolicy
{

    /**
     * Determine if the given user can view the gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function view(UserPolicy $user, Gebeco $gebeco)
    {
        if ($user->canDo('externaldatum.gebeco.view') && $user->isAdmin()) {
            return true;
        }

        return $gebeco->user_id == user_id() && $gebeco->user_type == user_type();
    }

    /**
     * Determine if the given user can create a gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('externaldatum.gebeco.create');
    }

    /**
     * Determine if the given user can update the given gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function update(UserPolicy $user, Gebeco $gebeco)
    {
        if ($user->canDo('externaldatum.gebeco.edit') && $user->isAdmin()) {
            return true;
        }

        return $gebeco->user_id == user_id() && $gebeco->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Gebeco $gebeco)
    {
        return $gebeco->user_id == user_id() && $gebeco->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Gebeco $gebeco)
    {
        if ($user->canDo('externaldatum.gebeco.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given gebeco.
     *
     * @param UserPolicy $user
     * @param Gebeco $gebeco
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Gebeco $gebeco)
    {
        if ($user->canDo('externaldatum.gebeco.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
