<?php

namespace Btravel\Externaldatum\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Externaldatum\Models\Tigges;

class TiggesPolicy
{

    /**
     * Determine if the given user can view the tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tigges $tigges)
    {
        if ($user->canDo('externaldatum.tigges.view') && $user->isAdmin()) {
            return true;
        }

        return $tigges->user_id == user_id() && $tigges->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('externaldatum.tigges.create');
    }

    /**
     * Determine if the given user can update the given tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tigges $tigges)
    {
        if ($user->canDo('externaldatum.tigges.edit') && $user->isAdmin()) {
            return true;
        }

        return $tigges->user_id == user_id() && $tigges->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tigges $tigges)
    {
        return $tigges->user_id == user_id() && $tigges->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tigges $tigges)
    {
        if ($user->canDo('externaldatum.tigges.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tigges.
     *
     * @param UserPolicy $user
     * @param Tigges $tigges
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tigges $tigges)
    {
        if ($user->canDo('externaldatum.tigges.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
