<?php

namespace Btravel\Externaldatum\Policies;

use Litepie\User\Contracts\UserPolicy;
use Btravel\Externaldatum\Models\Xplore;

class XplorePolicy
{

    /**
     * Determine if the given user can view the xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function view(UserPolicy $user, Xplore $xplore)
    {
        if ($user->canDo('externaldatum.xplore.view') && $user->isAdmin()) {
            return true;
        }

        return $xplore->user_id == user_id() && $xplore->user_type == user_type();
    }

    /**
     * Determine if the given user can create a xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('externaldatum.xplore.create');
    }

    /**
     * Determine if the given user can update the given xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function update(UserPolicy $user, Xplore $xplore)
    {
        if ($user->canDo('externaldatum.xplore.edit') && $user->isAdmin()) {
            return true;
        }

        return $xplore->user_id == user_id() && $xplore->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Xplore $xplore)
    {
        return $xplore->user_id == user_id() && $xplore->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Xplore $xplore)
    {
        if ($user->canDo('externaldatum.xplore.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given xplore.
     *
     * @param UserPolicy $user
     * @param Xplore $xplore
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Xplore $xplore)
    {
        if ($user->canDo('externaldatum.xplore.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
