<?php

namespace Btravel\Externaldatum\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Btravel\Externaldatum\Models\Externaldatum;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Btravel\Externaldatum\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/externaldatum/gebeco/*')) {
            Route::bind('gebeco', function ($gebeco) {
                $gebecorepo = $this->app->make('Btravel\Externaldatum\Interfaces\GebecoRepositoryInterface');
                return $gebecorepo->findorNew($gebeco);
            });
        }
        if (Request::is('*/externaldatum/tigges/*')) {
            Route::bind('tigges', function ($tigges) {
                $tiggesrepo = $this->app->make('Btravel\Externaldatum\Interfaces\TiggesRepositoryInterface');
                return $tiggesrepo->findorNew($tigges);
            });
        }
        if (Request::is('*/externaldatum/xplore/*')) {
            Route::bind('xplore', function ($xplore) {
                $xplorerepo = $this->app->make('Btravel\Externaldatum\Interfaces\XploreRepositoryInterface');
                return $xplorerepo->findorNew($xplore);
            });
        }
        if (Request::is('*/externaldatum/external_shipdata/*')) {
            Route::bind('external_shipdata', function ($external_shipdata) {
                $external_shipdatarepo = $this->app->make('Btravel\Externaldatum\Interfaces\ExternalShipdataRepositoryInterface');
                return $external_shipdatarepo->findorNew($external_shipdata);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
